Struct SysRegIo
Source pub struct SysRegIo<Spec: SystemRegisterSpec>();
An I/O backend for arm64 system registers.
The underlying base type of the register (assumed integral in
practice).
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.