SysReg

Type Alias SysReg 

pub type SysReg<Spec, Layout> = Register<Layout, <Spec as SystemRegisterSpec>::Access, SysRegIo<Spec>>;
Models an arm64 system register with a given layout.

It takes a system register ‘spec’ as a generic parameter, all of which have been stamped out in the regio::arm64::spec submodule with names equal to their official mnemonics.

Example usage:

use regio::arm64::{SysReg, spec};

const TPIDR_EL0: SysReg<spec::TPIDR_EL0, u64> = SysReg::new();

println!("TPIDR_EL0: {:#x}", TPIDR_EL0.read().get());

Aliased Type

pub struct SysReg<Spec, Layout> { /* private fields */ }

Implementations

Source

impl<Spec, Layout> SysReg<Spec, Layout>
where Spec: SystemRegisterSpec, Layout: LayoutOver<u64>,

pub const fn new() -> Self

Constructs a new system register instance.