pub enum UnsafeWrite {}Expand description
A tag for unsafe register write access: this is when writes to the register may contextually violate the memory model (e.g., system register that toggles the MMU or in modeling a page table entry as a register). In such cases, the user must attest to any given write being sound.