MmioBank

Struct MmioBank 

pub struct MmioBank<Base, MaxAccess: Accessible> { /* private fields */ }
Represents a contiguous region of memory containing registers. Contained registers are accessed via MmioBank::at and must feature access permissions narrower than MaxAccess.

Implementations

Source

impl<Base, MaxAccess> MmioBank<Base, MaxAccess>
where Base: Copy, MaxAccess: Accessible,

pub const fn new(base: MmioPtr<Base, MaxAccess>, size_bytes: usize) -> Self

Constructs a new bank from its base pointer and length.

pub const unsafe fn at<Layout, Access>( &self, offset: Offset<Layout, Access>, ) -> Mmio<Layout, Base, Access>
where Layout: LayoutOver<Base>, Access: Accessible, MaxAccess: AccessRestrictsTo<Access>,

Returns the memory-backed register at the specified offset into the bank.

Panics

Panics if the offset is misaligned for Base or exceeds the bounds of the bank.

Safety

Same as MmioPtr::new for underlying offset pointer.