Offset

Struct Offset 

pub struct Offset<Layout, Access> {
    pub value: usize,
    /* private fields */
}
Represents an in-memory register with a given layout and access permissions located at an offset from a base address.

Fields

value: usize

The offset in bytes.

Implementations

Source

impl<Layout, Access> Offset<Layout, Access>

pub const fn new(value: usize) -> Self