Register

Struct Register 

pub struct Register<Layout, Access, Io>
where Io: IoHandle, Layout: LayoutOver<<Io as IoHandle>::Base>, Access: Accessible,
{ /* private fields */ }
Register represents a structured register layout, and its access interface and permissions. This is the core abstraction of the crate.

If Access expresses unsafe-writability, then all write methods are marked as unsafe.

Implementations

Source

impl<Spec, Layout> Register<Layout, <Spec as SystemRegisterSpec>::Access, SysRegIo<Spec>>
where Spec: SystemRegisterSpec, Layout: LayoutOver<u64>,

pub const fn new() -> Self

Constructs a new system register instance.

Source

impl<Layout, Base, Access> Register<Layout, Access, MmioPtr<Base, Access>>
where Layout: LayoutOver<Base>, Base: Copy, Access: Accessible,

pub const fn new<InputAccess>(ptr: MmioPtr<Base, InputAccess>) -> Self
where InputAccess: AccessRestrictsTo<Access>,

Constructs a new memory-backed register from a pointer wrapper.

Source

impl<Encoding, Layout> Register<Layout, <Encoding as ControlAndStatusRegisterEncoding>::Access, CsrIo<Encoding>>
where Encoding: ControlAndStatusRegisterEncoding, Layout: LayoutOver<u64>,

pub const fn new() -> Self

Constructs a new CSR instance.

Source

impl<const N: u32, Layout> Register<Layout, <CrIo<N> as ControlRegister>::Access, CrIo<N>>
where CrIo<N>: ControlRegister, Layout: LayoutOver<u64>,

pub const fn new() -> Self

Constructs an x86-64 control register instance.

Source

impl<const N: u32, Layout> Register<Layout, <XcrIo<N> as ControlRegister>::Access, XcrIo<N>>
where XcrIo<N>: ControlRegister, Layout: LayoutOver<u64>,

pub const fn new() -> Self

Constructs an x86-64 control register instance.

Source

impl<const ID: u32, Layout, Access> Register<Layout, Access, MsrIo<ID>>
where Layout: LayoutOver<u64>, Access: Accessible,

pub const fn new() -> Self

Constructs an x86-64 MSR instance.

Source

impl<Layout, Base, Access> Register<Layout, Access, PortIo<Base, Access>>
where Layout: LayoutOver<Base>, Base: Copy, Access: Accessible,

pub const fn new(port: u16) -> Self

Constructs a new port register directly from a port address.

Source

impl<Layout, Access, Io> Register<Layout, Access, Io>
where Io: IoHandle, Layout: LayoutOver<<Io as IoHandle>::Base>, Access: Accessible,

pub const unsafe fn from_io(io: Io) -> Self

Constructs a new register from an I/O handle.

Safety

The caller must guarantee…

  • that the provided I/O handle meets the implementation-specific access safety preconditions for the duration of the lifetimes of the register instance and any copies of it (e.g., in the case of an MMIO pointer, that the pointer is aligned and the memory it points to remains mapped for those lifetimes);

  • and that Access correctly models the safe nature of access in this context.

pub const fn io(&self) -> &Io

pub fn into_io(self) -> Io

pub fn read(&self) -> Layout
where Access: Readable, Io: ReadHandle,

Reads from the register, if the backend and register permit it.

Source

impl<Layout, R, Io> Register<Layout, (R, SafeWrite), Io>
where Io: WriteHandle, Layout: LayoutOver<<Io as IoHandle>::Base>, (R, SafeWrite): Writable,

pub fn write(&self, value: Layout)

Writes to the register, if the backend and register permit it.

pub fn modify<ModifyFn, Ret>(&self, cb: ModifyFn) -> Ret
where (R, SafeWrite): Readable, Io: ReadHandle, ModifyFn: FnOnce(&mut Layout) -> Ret,

Modifies the contents of the register, if the register and backend admit both reads and writes, returning whatever state the modification callback wanted to forward.

pub fn atomic_swap(&self, value: Layout) -> Layout

Atomically swaps the contents of the register with the provided value, returning the original contents.

pub fn atomic_set_bits(&self, bits: Layout) -> Layout

Atomically sets the provided bits on the contents of the register, returning the original contents.

pub fn atomic_clear_bits(&self, bits: Layout) -> Layout

Atomically clears the provided bits on the contents of the register, returning the original contents.

Source

impl<Layout, R, Io> Register<Layout, (R, UnsafeWrite), Io>
where Io: WriteHandle, Layout: LayoutOver<<Io as IoHandle>::Base>, (R, UnsafeWrite): Writable,

pub unsafe fn write(&self, value: Layout)

Writes to the register, if the backend and register permit it.

Safety

The caller must guarantee that the write does not result in undefined behaviour.

pub unsafe fn modify<ModifyFn, Ret>(&self, cb: ModifyFn) -> Ret
where (R, UnsafeWrite): Readable, Io: ReadHandle, ModifyFn: FnOnce(&mut Layout) -> Ret,

Modifies the contents of the register, if the register and backend admit both reads and writes, returning whatever state the modification callback wanted to forward.

Safety

The caller must guarantee that the write does not result in undefined behaviour.

pub unsafe fn atomic_swap(&self, value: Layout) -> Layout

Atomically swaps the contents of the register with the provided value, returning the original contents.

Safety

The caller must guarantee that the write does not result in undefined behaviour.

pub unsafe fn atomic_set_bits(&self, bits: Layout) -> Layout

Atomically sets the provided bits on the contents of the register, returning the original contents.

Safety

The caller must guarantee that the write does not result in undefined behaviour.

pub unsafe fn atomic_clear_bits(&self, bits: Layout) -> Layout

Atomically clears the provided bits on the contents of the register, returning the original contents.

Safety

The caller must guarantee that the write does not result in undefined behaviour.