ReadHandle

Trait ReadHandle 

pub trait ReadHandle: IoHandle {
    // Required method
    unsafe fn read_raw(&self) -> Self::Base;
}
Represents an abstracted means of register reads.

Required Methods

unsafe fn read_raw(&self) -> Self::Base

Performs the read.

Safety

The caller must guarantee that the implementation-specific preconditions for a sound read are met. For example, in the case of a pointer, that the instance is valid, properly aligned, and pointing to initialized memory.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl ReadHandle for CrIo<0>

Source

impl ReadHandle for CrIo<2>

Source

impl ReadHandle for CrIo<3>

Source

impl ReadHandle for CrIo<4>

Source

impl ReadHandle for CrIo<8>

Source

impl<Access: Readable> ReadHandle for PortIo<u8, Access>

Source

impl<Access: Readable> ReadHandle for PortIo<u16, Access>

Source

impl<Access: Readable> ReadHandle for PortIo<u32, Access>

Source

impl<Access: Readable> ReadHandle for PortIo<u64, Access>

Source

impl<Access> ReadHandle for MmioPtr<u8, Access>
where Access: Readable,

Source

impl<Access> ReadHandle for MmioPtr<u16, Access>
where Access: Readable,

Source

impl<Access> ReadHandle for MmioPtr<u32, Access>
where Access: Readable,

Source

impl<Access> ReadHandle for MmioPtr<u64, Access>
where Access: Readable,

Source

impl<const ID: u32> ReadHandle for MsrIo<ID>