RwSafeReg

Trait RwSafeReg 

pub trait RwSafeReg<Layout>: ReadReg<Layout> + SafeWriteReg<Layout> { }
A trait representing a register that is both readable and safe-writable. It is automatically implemented for any type that implements both ReadReg and SafeWriteReg.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Layout, R> RwSafeReg<Layout> for R
where R: ReadReg<Layout> + SafeWriteReg<Layout>,