RwUnsafeReg

Trait RwUnsafeReg 

pub trait RwUnsafeReg<Layout>: ReadReg<Layout> + UnsafeWriteReg<Layout> { }
A trait representing a register that is both readable and unsafe-writable. It is automatically implemented for any type that implements both ReadReg and UnsafeWriteReg.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Layout, R> RwUnsafeReg<Layout> for R
where R: ReadReg<Layout> + UnsafeWriteReg<Layout>,