CpuidValue

Struct CpuidValue 

pub struct CpuidValue<const LEAF: u32, const SUBLEAF: u32, const REG: u8, Layout: LayoutOver<u32>>(/* private fields */);
A marker for the CPUID layout associated with a particular leaf, subleaf, and output register.

The output register, REG, must be one of EAX, EBX, ECX, or EDX.

Implementations

Source

impl<const LEAF: u32, const SUBLEAF: u32, const REG: u8, Layout: LayoutOver<u32>> CpuidValue<LEAF, SUBLEAF, REG, Layout>

pub const fn new() -> Self

pub const fn leaf(&self) -> u32

The associated leaf.

Despite being a part of the type itself, it is convenient to have this accessible as an accessor, given that it is expected that one would be primarily dealing in const Cpuid objects.

pub const fn subleaf(&self) -> u32

The associated subleaf.

Despite being a part of the type itself, it is convenient to have this accessible as an accessor, given that it is expected that one would be primarily dealing in const Cpuid objects.