Struct CrIo
Source pub struct CrIo<const N: u32> {}
A simple I/O backend for reading from and writing to control registers.
The underlying base type of the register (assumed integral in
practice).
Performs the write of the provided value.
Read more
Performs the write of the provided value.
Read more
Performs the write of the provided value.
Read more
Performs the write of the provided value.
Read more
Performs the write of the provided value.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.