pub struct MmioPtr<T, Access: Accessible>(/* private fields */);Expand description
Represents a pointer to an MMIO address - with specific access permissions - at which a register might be located.
Implementations
Sourceimpl<T, R> MmioPtr<T, (R, NoWrite)>where
(R, NoWrite): Accessible,
impl<T, R> MmioPtr<T, (R, NoWrite)>where
(R, NoWrite): Accessible,
Sourcepub const unsafe fn new(ptr: *const T) -> Self
pub const unsafe fn new(ptr: *const T) -> Self
Constructs a new, read-only MMIO pointer wrapper.
Safety
The caller must guarantee the safety preconditions of
[core::ptr::read_volatile()] for the lifetime of MmioPtr. In
particular…
-
that
ptris aligned and points to a mapped MMIO address; -
the mapping remains valid for the lifetime of the returned
MmioPtr(and any copies of it); -
accesses must never trap.
Note that it is not assumed that the backing memory is immutable.
Sourceimpl<T, Access: Writable> MmioPtr<T, Access>
impl<T, Access: Writable> MmioPtr<T, Access>
Sourcepub const unsafe fn new(ptr: *mut T) -> Self
pub const unsafe fn new(ptr: *mut T) -> Self
Constructs a new, writable MMIO pointer wrapper.
Safety
The caller must guarantee the safety preconditions of
[core::ptr::read_volatile()] (if readable) and
[core::ptr::write_volatile()] for the lifetime of MmioPtr. In
particular…
-
that
ptris aligned and points to a mapped MMIO address; -
the mapping remains valid for the lifetime of the returned
MmioPtr(and any copies of it); -
accesses must never trap.
Also,
- If
Accessexpresses safe-writability (seeSafeWrite), that writing any value whatsoever to this address cannot result in undefined behaviour.
Note that it is not assumed that the backing memory is immutable, or
that a writable MmioPtr has exclusive access to it.
Sourceimpl<T, Access: Accessible> MmioPtr<T, Access>
impl<T, Access: Accessible> MmioPtr<T, Access>
Sourcepub const fn restrict<NewAccess>(self) -> MmioPtr<T, NewAccess>where
NewAccess: Accessible,
Access: AccessRestrictsTo<NewAccess>,
pub const fn restrict<NewAccess>(self) -> MmioPtr<T, NewAccess>where
NewAccess: Accessible,
Access: AccessRestrictsTo<NewAccess>,
Restricts the access permissions of this pointer.