pub struct Offset<Layout, Access> {
pub value: usize,
/* private fields */
}Expand description
Represents an in-memory register with a given layout and access permissions located at an offset from a base address.
Fields
value: usizeThe offset in bytes.
Implementations