pub trait LayoutOver<Base>:
Copy
+ From<Base>
+ Into<Base> { }Expand description
A convenience supertrait for the traits expected of layout types over a specific base type. This is not intended to be implemented explicitly, only through its blanket implementation.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".