pub trait RwUnsafeReg<Layout>: ReadReg<Layout> + UnsafeWriteReg<Layout> { }Expand description
A trait representing a register that is both readable and unsafe-writable.
It is automatically implemented for any type that implements both
ReadReg and UnsafeWriteReg.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".